/*
 *  UFTP - UDP based FTP with multicast
 *
 *  Copyright (C) 2001-2009   Dennis A. Bush, Jr.   bush@tcnj.edu
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <winsock2.h>
#include "winsock_err.h"

struct _winsock_err winsock_err[50] = {
  { WSAEINTR,               "Interrupted function call." },
  { WSAEACCES,              "Permission denied." },
  { WSAEFAULT,              "Bad address." },
  { WSAEINVAL,              "Invalid argument." },
  { WSAEMFILE,              "Too many open files." },
  { WSAEWOULDBLOCK,         "Resource temporarily unavailable." },
  { WSAEINPROGRESS,         "Operation now in progress." },
  { WSAEALREADY,            "Operation already in progress." },
  { WSAENOTSOCK,            "Socket operation on nonsocket." },
  { WSAEDESTADDRREQ,        "Destination address required." },
  { WSAEMSGSIZE,            "Message too long." },
  { WSAEPROTOTYPE,          "Protocol wrong type for socket." },
  { WSAENOPROTOOPT,         "Bad protocol option." },
  { WSAEPROTONOSUPPORT,     "Protocol not supported." },
  { WSAESOCKTNOSUPPORT,     "Socket type not supported." },
  { WSAEOPNOTSUPP,          "Operation not supported." },
  { WSAEPFNOSUPPORT,        "Protocol family not supported." },
  { WSAEAFNOSUPPORT,        "Address family not supported by protocol family." },
  { WSAEADDRINUSE,          "Address already in use." },
  { WSAEADDRNOTAVAIL,       "Cannot assign requested address." },
  { WSAENETDOWN,            "Network is down." },
  { WSAENETUNREACH,         "Network is unreachable." },
  { WSAENETRESET,           "Network dropped connection on reset." },
  { WSAECONNABORTED,        "Software caused connection abort." },
  { WSAECONNRESET,          "Connection reset by peer." },
  { WSAENOBUFS,             "No buffer space available." },
  { WSAEISCONN,             "Socket is already connected." },
  { WSAENOTCONN,            "Socket is not connected." },
  { WSAESHUTDOWN,           "Cannot send after socket shutdown." },
  { WSAETIMEDOUT,           "Connection timed out." },
  { WSAECONNREFUSED,        "Connection refused." },
  { WSAEHOSTDOWN,           "Host is down." },
  { WSAEHOSTUNREACH,        "No route to host." },
  { WSAEPROCLIM,            "Too many processes." },
  { WSASYSNOTREADY,         "Network subsystem is unavailable." },
  { WSAVERNOTSUPPORTED,     "Winsock.dll version out of range." },
  { WSANOTINITIALISED,      "Successful WSAStartup not yet performed." },
  { WSAEDISCON,             "Graceful shutdown in progress." },
  { WSATYPE_NOT_FOUND,      "Class type not found." },
  { WSAHOST_NOT_FOUND,      "Host not found." },
  { WSATRY_AGAIN,           "Nonauthoritative host not found." },
  { WSANO_RECOVERY,         "This is a nonrecoverable error." },
  { WSANO_DATA,             "Valid name, no data record of requested type." },
  { WSA_INVALID_HANDLE,     "Specified event object handle is invalid." },
  { WSA_INVALID_PARAMETER,  "One or more parameters are invalid." },
  { WSA_IO_INCOMPLETE,      "Overlapped I/O event object not in signaled state." },
  { WSA_IO_PENDING,         "Overlapped operations will complete later." },
  { WSA_NOT_ENOUGH_MEMORY,  "Insufficient memory available." },
  { WSA_OPERATION_ABORTED,  "Overlapped operation aborted." },
  { WSASYSCALLFAILURE,      "System call failure." }
};

const char *GetWinsockErrString(int err)
{
  int i;
  for (i=0;i<50;i++) {
    if (winsock_err[i].code==err) {
      return winsock_err[i].message;
    }
  }
  return "Unknown error";
}
